; --COPYRIGHT--,BSD_EX
;  Copyright (c) 2012, Texas Instruments Incorporated
;  All rights reserved.
; 
;  Redistribution and use in source and binary forms, with or without
;  modification, are permitted provided that the following conditions
;  are met:
; 
;  *  Redistributions of source code must retain the above copyright
;     notice, this list of conditions and the following disclaimer.
; 
;  *  Redistributions in binary form must reproduce the above copyright
;     notice, this list of conditions and the following disclaimer in the
;     documentation and/or other materials provided with the distribution.
; 
;  *  Neither the name of Texas Instruments Incorporated nor the names of
;     its contributors may be used to endorse or promote products derived
;     from this software without specific prior written permission.
; 
;  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
;  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
;  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
;  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
;  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
;  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
;  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
;  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
;  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
;  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
;  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
; 
; ******************************************************************************
;  
;                        MSP430 CODE EXAMPLE DISCLAIMER
; 
;  MSP430 code examples are self-contained low-level programs that typically
;  demonstrate a single peripheral function or device feature in a highly
;  concise manner. For this the code may rely on the device's power-on default
;  register values and settings such as the clock configuration and care must
;  be taken when combining code from several examples to avoid potential side
;  effects. Also see www.ti.com/grace for a GUI- and www.ti.com/msp430ware
;  for an API functional library-approach to peripheral configuration.
; 
; --/COPYRIGHT--
;******************************************************************************
;  MSP430x47x Demo - DAC12_0, Output Voltage Ramp on DAC0, DAC1 Constant, DAC ISR
;
;  Description: Using DAC12.0 outputs a 16 Step Ramp with 1 sample/sec
;  using Timer_B2 trigger. Ramp is output on P1.6. Normal mode is LPM3.
;  DAC1 outputs a constant 1.2V on P1.4.
;  Use internal 1.2V Vref.
;
;               MSP430x47x
;            -----------------
;        /|\|              XIN|-
;         | |                 |
;         --|RST          XOUT|-
;           |                 |
;           |        DAC0/P1.4|--> Ramp_positive
;           |        DAC1/P1.6|--> 1.2V
;
;   P.Thanigai
;   Texas Instruments Inc.
;   September 2008
;   Built with Code Composer Essentials Version: 3.0
;******************************************************************************
 .cdecls C,LIST, "msp430.h" 
;-------------------------------------------------------------------------------
            .def    RESET                   ; Export program entry-point to
                                            ; make it known to linker.

;------------------------------------------------------------------------------
            .text                           ; Program Start
;------------------------------------------------------------------------------
RESET       mov.w   #0A00h,SP               ; Initialize stack pointer
StopWDT     mov     #WDTPW+WDTHOLD,&WDTCTL  ; Stop Watchdog Timer
SetupSD16   mov.w   #SD16REFON,&SD16CTL     ; Internal 1.2V ref on
            mov.w   #OUTMOD_7,&TBCCTL2      ; Reset/set
            mov.w   #16384,&TBCCR2          ; PWM Duty Cycle
            mov.w   #32767,&TBCCR0          ; 1Hz Clock period
            mov.w   #TBSSEL_1+MC_1,&TBCTL   ; ACLK, up mode
SetupDAC120 mov.w   #DAC12IR + DAC12AMP_5 + DAC12ENC + DAC12SREF_3 + DAC12CALON + DAC12OPS + DAC12IE + DAC12LSEL_3,&DAC12_0CTL
SetupDAC121 mov.w   #DAC12IR + DAC12AMP_5 + DAC12ENC + DAC12SREF_3 + DAC12CALON + DAC12OPS,&DAC12_1CTL
            mov.w   #0FFFh,&DAC12_1DAT      ; 1.2V
            eint                            ; Interrupts enabled
            inc.w   &DAC12_0DAT             ; Positive ramp
            bis.w   #LPM3,SR                ; Enter LPM3

;------------------------------------------------------------------------------
DAC12_ISR;    Common ISR for DAC12 and DMA
;------------------------------------------------------------------------------
            bic     #DAC12IFG,&DAC12_0CTL
            add     #256,&DAC12_0DAT
            and.w   #0FFFh,&DAC12_0DAT      ;
            reti
;-----------------------------------------------------------------------------
;           Interrupt Vectors Used
;-----------------------------------------------------------------------------
            .sect   ".reset"                ; MSP430 RESET Vector
            .short  RESET                   ;
            .sect   ".int03"                     ; MSP430 RESET Vector
            .short  DAC12_ISR 
            .end
